pub struct PulldownHighlighter { /* private fields */ }Implementations
Sourceimpl PulldownHighlighter
A highlighter that can be instantiated once and used many times for better performance.
impl PulldownHighlighter
A highlighter that can be instantiated once and used many times for better performance.
pub fn new(theme: &str) -> Result<PulldownHighlighter, Error>
Sourcepub fn highlight<'a, It>(&self, events: It) -> Result<Vec<Event<'a>>, Error>
pub fn highlight<'a, It>(&self, events: It) -> Result<Vec<Event<'a>>, Error>
Apply syntax highlighting to pulldown-cmark events using this instance’s theme.
Take an iterator over pulldown-cmark’s events, and (on success) return a new iterator where code blocks have been turned into HTML text blocks with syntax highlighting.
Implementation based on https://github.com/raphlinus/pulldown-cmark/issues/167#issuecomment-448491422.